@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.13"
+__version__ = "1.0.14"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -148,4 +148,4 @@ def deprecated(func, msg=None):
 @deprecated
 class Context(Auth):
     def __init__(self, user, password, api):
-        super(Context, self).__init__(user, password, api)
\ No newline at end of file
+        Auth.__init__(self, user, password, api)
\ No newline at end of file
